@@ -5,6 +5,14 @@
 import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
+# Surpressing Tensorflow Warnings
+import os
+import time
+os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2' 
+# 0 = all messages are logged (default behavior)
+# 1 = INFO messages are not printed
+# 2 = INFO and WARNING messages are not printed
+# 3 = INFO, WARNING, and ERROR messages are not printed
 
 
 def preprocess(DIR, categories, size, isSave=True ):
@@ -98,4 +106,4 @@ def imageDataGenerator():
     # We do not augment the validation data
     val_datagen = ImageDataGenerator()
 
-    return train_datagen, val_datagen
+    return train_datagen, val_datagen
\ No newline at end of file
